@@ -2,7 +2,7 @@ package Net::Twitter::Search;
 use Moose;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.07003';
+our $VERSION = '3.07004';
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
 extends 'Net::Twitter::Core';
@@ -26,7 +26,7 @@ Net::Twitter::Search - A perl interface to the Twitter Search API
 
   $nt = Net::Twitter::Search->new;
 
-  $tweets = $nt->search('net_twitter');
+  $tweets = $nt->search('perl_api');
 
 =head1 DESCRIPTION
 
